@@ -28,7 +28,7 @@ sub valid_args {
         {
             expected => "<123>",
             #args => [ "Prompt: ", { no_echo => 2, default => 123 } ],
-            args => [ "Prompt: ", { no_echo => 1, default => 123 } ],
+            args => [ "Prompt: ", { no_echo => 2, default => '123' } ],
         },
     ];
 }
