@@ -9,13 +9,10 @@ use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Readline;
 
-my $tiny = Term::ReadLine::Simple->new();
-
 my $a_ref = Data_Test_Readline::return_test_data();
+my $args  = $a_ref->[shift]{arguments};
 
-for my $ref ( $a_ref->[shift] ) {
-    my $args  = $ref->{arguments};
+my $tiny = Term::ReadLine::Simple->new();
+my $line = $tiny->readline( @$args );
 
-    my $line = $tiny->readline( @$args );
-    print "<$line>\n";
-}
+print "<$line>\n";
